@@ -107,3 +107,28 @@ setGeneric("%in%")
 setGeneric("zcl", function (x) standardGeneric("zcl"))
 setGeneric("absolute.zcl", function (x) standardGeneric("absolute.zcl"))
 
+
+##' toJSON methods for Crunch objects
+##'
+##' \code{crunch} uses the \code{jsonlite} package for (de)serialization of
+##' JSON. Unlike \code{\link[RJSONIO]{toJSON}}, \code{\link[jsonlite]{toJSON}}
+##' does not allow for defining S4 methods for other object types. So,
+##' \code{crunch::toJSON} wraps \code{jsonprep}, which exists to translate 
+##' objects to base R objects, which \code{jsonlite::toJSON} can handle. 
+##' \code{jsonprep} is defined as an S4 generic, and it is exported (unlike
+##' code{jsonlite::asJSON}), so you can define methods for it if you have other
+##' objects that you want to successfully serialize to JSON.
+##' 
+##' @param x the object
+##' @param ... additional arguments
+##' @return \code{jsonprep} returns a base R object that \code{jsonlite::toJSON}
+##' can handle. \code{toJSON} returns the JSON-serialized character object.
+##' @name tojson-crunch
+##' @seealso \code{\link[jsonlite]{toJSON}}
+NULL
+
+##' @rdname tojson-crunch
+##' @export
+setGeneric("jsonprep", function (x, ...) standardGeneric("jsonprep"))
+
+
