@@ -17,6 +17,7 @@ NULL
 ##' @rdname tuple-methods
 ##' @export
 setMethod("refresh", "IndexTuple", function (x) {
+    dropCache(x@index_url)
     catalog <- ShojiCatalog(crGET(x@index_url))
     x@body <- catalog[[x@entity_url]]
     return(x)
@@ -67,7 +68,9 @@ setMethod("entity", "DatasetTuple", function (x) {
 
 ##' @rdname tuple-methods
 ##' @export
-setMethod("delete", "IndexTuple", function (x) crDELETE(x@entity_url))
+setMethod("delete", "IndexTuple", function (x) {
+    crDELETE(x@entity_url, drop=dropCache(x@index_url))
+})
 ##' @rdname tuple-methods
 ##' @export
 setMethod("delete", "DatasetTuple", function (x, confirm=interactive(), ...) {
